@@ -1,5 +1,5 @@
 /* This file is part of Metaproxy.
-   Copyright (C) 2005-2010 Index Data
+   Copyright (C) 2005-2012 Index Data
 
 Metaproxy is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free
@@ -23,9 +23,12 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 namespace mp = metaproxy_1;
 
-void mp::filter::Base::configure(const xmlNode * ptr, bool test_only)
+void mp::filter::Base::start() const
+{
+}
+
+void mp::filter::Base::stop() const
 {
-    mp::xml::check_empty(ptr);
 }
 
 /*
